==> pmml-model-1.1.0-sources.jar: org/dmg/pmml/FieldUsageType.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FIELD-USAGE-TYPE.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="FIELD-USAGE-TYPE">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="active"/>
 *     &lt;enumeration value="predicted"/>
 *     &lt;enumeration value="supplementary"/>
 *     &lt;enumeration value="group"/>
 *     &lt;enumeration value="order"/>
 *     &lt;enumeration value="frequencyWeight"/>
 *     &lt;enumeration value="analysisWeight"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "FIELD-USAGE-TYPE")
@XmlEnum
public enum FieldUsageType {

    @XmlEnumValue("active")
    ACTIVE("active"),
    @XmlEnumValue("predicted")
    PREDICTED("predicted"),
    @XmlEnumValue("supplementary")
    SUPPLEMENTARY("supplementary"),
    @XmlEnumValue("group")
    GROUP("group"),
    @XmlEnumValue("order")
    ORDER("order"),
    @XmlEnumValue("frequencyWeight")
    FREQUENCY_WEIGHT("frequencyWeight"),
    @XmlEnumValue("analysisWeight")
    ANALYSIS_WEIGHT("analysisWeight");
    private final String value;

    FieldUsageType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static FieldUsageType fromValue(String v) {
        for (FieldUsageType c: FieldUsageType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> pmml-model-1.1.1-sources.jar: org/dmg/pmml/FieldUsageType.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FIELD-USAGE-TYPE.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="FIELD-USAGE-TYPE">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="active"/>
 *     &lt;enumeration value="predicted"/>
 *     &lt;enumeration value="target"/>
 *     &lt;enumeration value="supplementary"/>
 *     &lt;enumeration value="group"/>
 *     &lt;enumeration value="order"/>
 *     &lt;enumeration value="frequencyWeight"/>
 *     &lt;enumeration value="analysisWeight"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "FIELD-USAGE-TYPE")
@XmlEnum
public enum FieldUsageType {

    @XmlEnumValue("active")
    ACTIVE("active"),
    @XmlEnumValue("predicted")
    PREDICTED("predicted"),
    @XmlEnumValue("target")
    @Schema(min = Version.PMML_4_2)
    TARGET("target"),
    @XmlEnumValue("supplementary")
    SUPPLEMENTARY("supplementary"),
    @XmlEnumValue("group")
    GROUP("group"),
    @XmlEnumValue("order")
    ORDER("order"),
    @XmlEnumValue("frequencyWeight")
    @Schema(min = Version.PMML_4_0)
    FREQUENCY_WEIGHT("frequencyWeight"),
    @XmlEnumValue("analysisWeight")
    @Schema(min = Version.PMML_4_0)
    ANALYSIS_WEIGHT("analysisWeight");
    private final String value;

    FieldUsageType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static FieldUsageType fromValue(String v) {
        for (FieldUsageType c: FieldUsageType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
